COMMAND_NAME_DEPENDENCIES_CHECK_VERSION = 'dependencies_check_version'
COMMAND_NAME_DEPENDENCIES_INSTALL = 'dependencies_install'
COMMAND_NAME_DEPENDENCIES_SHOW_VERSION = 'dependencies_show_version'

MAYAN_PYPI_NAME = 'mayan-edms'

MESSAGE_NOT_LATEST = '''The version you are using is outdated. The latest
version is %s'''
MESSAGE_UNKNOWN_VERSION = '''It is not possible to determine the latest
version available.'''
MESSAGE_UNEXPECTED_ERROR = '''Unexpected error trying to determine the
latest version available. Make sure your installation has a connection to
the internet; %s'''
MESSAGE_UP_TO_DATE = 'Your version is up-to-date.'

PYPI_URL = 'https://pypi.org'
